@@ -125,15 +125,21 @@ def cleanup_df(
     target,
     train_index=None,
     use_categories=None,
+    use_nulls=None,
 ):
     use_categories = default_value(use_categories, True)
+    use_nulls = default_value(use_nulls, False)
+
     X, y = xy_df(df=df, train_index=train_index, target=target)
 
-    # TODO: allow using catboost null handling capabilty
-    X = fill_nulls_naively(X)
-
     cat_cols = X.select_dtypes(exclude=["number", "bool", "datetime"]).columns
 
+    # allow using catboost null handling capability
+    if not use_nulls:
+        X = fill_nulls_naively(X)
+    else:
+        X[cat_cols] = X[cat_cols].fillna("LITELEARN_NA_VALUE").astype("string")
+
     for col in cat_cols:
         if not use_categories:
             print(f"casting {col} onto category codes")
